@@ -3,7 +3,7 @@ import os
 from akerbp.mlops.core import logger
 
 
-logging=logger.get_logger(name='MLOps')
+logging=logger.get_logger(name='mlops_core')
 
 def get_top_folder(s):
     return s.split(os.sep)[0]
