@@ -2,7 +2,7 @@
 import sys
 import os
 
-from importlib import resources as importlib_resources
+from importlib import import_module, resources as importlib_resources
 import shutil
 import subprocess
 
@@ -11,7 +11,8 @@ from akerbp.mlops.core import logger, config
 
 logging=logger.get_logger(name='mlops_deployment')
 
-locals().update(config.getenv)
+env = config.envs.env
+service_name = config.envs.service_name
 
 
 def get_version():
@@ -119,7 +120,7 @@ def install_requirements(req_file):
     subprocess.check_call(c)
 
 
-def set_up_requirements(model_req_file):
+def set_up_requirements(c):
     """
     Set up a "requirements.txt" file at the top of the deployment folder
     (assumed to be the current directory) and install dependencies (unless in
@@ -127,7 +128,16 @@ def set_up_requirements(model_req_file):
     """
     logging.info("Create requirement file")
     if "akerbp/mlops" in get_repo_origin():
-        set_mlops_import(model_req_file)
-    shutil.move(model_req_file, 'requirements.txt')
+        set_mlops_import(c.req_file)
+    shutil.move(c.req_file, 'requirements.txt')
+    c.req_file = 'requirements.txt'
     if env != "dev":
         install_requirements('requirements.txt')
+
+
+
+def get_model_test_data(test_import_path):
+    service_test = import_module(test_import_path).ServiceTest()
+    input = getattr(service_test, f"{service_name}_input")
+    check = getattr(service_test, f"{service_name}_check")
+    return input, check
\ No newline at end of file
