@@ -7,14 +7,12 @@ Requirement: SDK activated and GOOGLE_APPLICATION_CREDENTIALS defined
 """
 
 import subprocess
-import os
-
 import requests
 import json
 
-
 from akerbp.mlops.core import config, logger 
-locals().update(config.getenv)
+google_project_id = config.envs.google_project_id
+service_name = config.envs.service_name
 logging=logger.get_logger(name='mlops_gc')
 
 
@@ -89,7 +87,7 @@ def run_container(image_name, service_account):
     Run container with a service account
     """
     logging.info(f"Run container, {image_name=}, {service_account=}")
-    env_vars = {k.upper():v for k,v in config.getenv.items() if v}
+    env_vars = {k.upper():v for k,v in config.envs_dir.items() if v}
     env_vars.update(dict(DEPLOYMENT_PLATFORM='cdf'))    
     env_vars = [f"{k}={v}" for k,v in env_vars.items() if v]
     env_vars=','.join(env_vars)
