@@ -40,7 +40,7 @@ def upload_new_model_version(model_name, env, folder, metadata):
     """
 
     file_list = cdf.query_file_versions(
-        f"{model_name}/{env}/", 
+        external_id_prefix= f"{model_name}/{env}/", 
         directory_prefix='/mlops', 
         uploaded=None # count any file
     )
